clear all; close all; clc;

%% Loading full data
datafull = xlsread('Trans_Aus_Dat_dynare.xls','Trans_Aus_Dat','A2:N93');
tim =linspace(1992,2016, length(datafull(:,1)));
T =length(datafull(:,1));

%% Preliminary for rolling window
bw =1;                           % first obs of the first window
ew =60;                          % final obs of the first window
hmax=12;                         % maximum step-ahead-forecast or maximum forecast horizon
nr_window = (T - hmax) - ew + 1; % number of window

%% Creating matrix to store the predicted values and the predicted errors

forcast_open_pi_obs=zeros(nr_window,hmax);  % storing the forecasted value of inflation
forcast_open_wp_obs=zeros(nr_window,hmax);  % storing the forecasted value of wage
forcast_open_c_obs=zeros(nr_window,hmax);   % storing the forecasted value of consumption
forcast_open_i_obs=zeros(nr_window,hmax);   % storing the forecasted value of investment
forcast_open_r_obs=zeros(nr_window,hmax);   % storing the forecasted value of interest rate
forcast_open_E_obs=zeros(nr_window,hmax);   % storing the forecasted value of employment
forcast_open_y_obs=zeros(nr_window,hmax);   % storing the forecasted value of output


fems_open_pi=zeros(nr_window,hmax);         % storing the forecasted error of inflation
fems_open_wp=zeros(nr_window,hmax);         % storing the forecasted error of wage
fems_open_c=zeros(nr_window,hmax);          % storing the forecasted error of consumption
fems_open_i=zeros(nr_window,hmax);          % storing the forecasted error of investment
fems_open_R=zeros(nr_window,hmax);          % storing the forecasted error of interest rate
fems_open_E=zeros(nr_window,hmax);          % storing the forecasted error of employment
fems_open_y=zeros(nr_window,hmax);          % storing the forecasted error of output

nowindow=zeros(nr_window,2);        

%% Store data temperorily to plot and check forecasting performance of each window

forcast_plot_pi_obs=zeros(1,hmax);
forcast_plot_wp_obs=zeros(1,hmax);
forcast_plot_c_obs=zeros(1,hmax);
forcast_plot_c_obs=zeros(1,hmax);
forcast_plot_i_obs=zeros(1,hmax);
forcast_plot_r_obs=zeros(1,hmax);
forcast_plot_E_obs=zeros(1,hmax);
forcast_plot_y_obs=zeros(1,hmax);


%% Rolling Window

while  ew <=  T - hmax

nowindow(bw,1)=bw;
nowindow(bw,2)=ew; 
save('nowindow','nowindow','-ascii','-double');

% cut data for current window
data_current_window=datafull(bw:ew,:); 

filename = 'Trans_Aus_Dat_dynare_rw.xlsx';

names = {'data_pid','data_wp','data_c',...
    'data_i','x_hat','data_R','E_t','data_y',...
    'data_x','data_m','data_pic','data_ystar',...
    'data_pistar','data_Rstar'};
 xlswrite(filename,data_current_window, 'Sheet1', 'A2');
 xlswrite(filename, names, 'Sheet1', 'A1');

% calling Dynare function (version 4.4)
dynare ausopen noclearall 


%% Storing the forecasted values of the 1,2,3,...12-step-ahead
% Note that: Dynare 4.4 report the forecasting values for 12 horizon from 2th to 13th column
% That's why the following index i runs from 2 to 13

for i=2:13 

% [01] storing the forecasted value of inflation
forcast_open_pi_obs(bw,i-1) =oo_.PointForecast.Mean.data_pid(i);   
save('forcast_open_pi_obs','forcast_open_pi_obs','-ascii','-double');
forcast_plot_pi_obs(1,i-1)=oo_.PointForecast.Mean.data_pid(i);

% [02]storing the forecasted value of wage
forcast_open_wp_obs(bw,i-1) =oo_.PointForecast.Mean.data_wp(i);    
save('forcast_open_wp_obs','forcast_open_wp_obs','-ascii','-double');
forcast_plot_wp_obs(1,i-1)=oo_.PointForecast.Mean.data_wp(i);

% [03]storing the forecasted value of consumption
forcast_open_c_obs(bw,i-1)  =oo_.PointForecast.Mean.data_c(i);     
save('forcast_open_c_obs','forcast_open_c_obs','-ascii','-double');
forcast_plot_c_obs(1,i-1)=oo_.PointForecast.Mean.data_c(i); 

% [04] storing the forecasted value of investment
forcast_open_i_obs(bw,i-1)  =oo_.PointForecast.Mean.data_i(i);     
save('forcast_open_i_obs','forcast_open_i_obs','-ascii','-double');
forcast_plot_i_obs(1,i-1)=oo_.PointForecast.Mean.data_i(i);

% [05] storing the forecasted value of interest rate
forcast_open_r_obs(bw,i-1)  =oo_.PointForecast.Mean.data_R(i);     
save('forcast_open_r_obs','forcast_open_r_obs','-ascii','-double');
forcast_plot_r_obs(1,i-1)=oo_.PointForecast.Mean.data_R(i);

% [06] storing the forecasted value of employment
forcast_open_E_obs(bw,i-1)  =oo_.PointForecast.Mean.E_t(i);       
save('forcast_open_E_obs','forcast_open_E_obs','-ascii','-double');
forcast_plot_E_obs(1,i-1)=oo_.PointForecast.Mean.E_t(i);

% [07] storing the forecasted value of output
forcast_open_y_obs(bw,i-1)  =oo_.PointForecast.Mean.data_y(i);    
save('forcast_open_y_obs','forcast_open_y_obs','-ascii','-double');
forcast_plot_y_obs(1,i-1)=oo_.PointForecast.Mean.data_y(i);

end

%% Computing and storing the error of forecast

for i=1:12
    
%[01] computing and storing the forecasted error of inflation
% Note that: the actual value of inflation locates at the 1th columne of datafull
fems_open_pi(bw,i) =datafull(ew+i,1)-forcast_open_pi_obs(bw,i); 
save('fems_open_pi','fems_open_pi','-ascii','-double');

% [02] computing and storing the forecasted error of wage
% Note that: the actual value of wage locates at the 2th columne of datafull
fems_open_wp(bw,i) =datafull(ew+i,2)-forcast_open_wp_obs(bw,i); 
save('fems_open_wp','fems_open_wp','-ascii','-double');

% [03] computing and storing the forecasted error of consumption
% Note that: the actual value of consumption locates at the 3th columne of datafull
fems_open_c(bw,i)  =datafull(ew+i,3)-forcast_open_c_obs(bw,i);
save('fems_open_c','fems_open_c','-ascii','-double');

% [04]computing and storing the forecasted error of investment
% Note that: the actual value of investment locates at the 4th columne of datafull
fems_open_i(bw,i)  =datafull(ew+i,4)-forcast_open_i_obs(bw,i); 
save('fems_open_i','fems_open_i','-ascii','-double');

% [05]computing and storing the forecasted error of interest rate
% Note that: the actual value of interest rate locates at the 6th columne of datafull
fems_open_R(bw,i)  =datafull(ew+i,6)-forcast_open_r_obs(bw,i); 
save('fems_open_R','fems_open_R','-ascii','-double');

% [06]computing and storing the forecasted error of employment
% Note that: the actual value of employment locates at the 7th columne of datafull
fems_open_E(bw,i)  =datafull(ew+i,7)-forcast_open_E_obs(bw,i); 
save('fems_open_E','fems_open_E','-ascii','-double');

% [07]computing and storing the forecasted error of output
% Note that: the actual value of output locates at the 8th columne of datafull
fems_open_y(bw,i)  =datafull(ew+i,8)-forcast_open_y_obs(bw,i); 
save('fems_open_y','fems_open_y','-ascii','-double');

end

%% Plot figure for forecasted value in each window to check the forecasting performance of current window

forcast_open_current_window= zeros(ew+hmax,14);

% taking the actual value of current window
for j=1:14
 for i=1:ew
 forcast_open_current_window(i,j)=datafull(i,j)
 end
end

% fulfiling the 12-step-ahead forecasted value
for i=1:12    
forcast_open_current_window(ew+i,1)=forcast_plot_pi_obs(1,i)'
forcast_open_current_window(ew+i,2)=forcast_plot_wp_obs(1,i)'
forcast_open_current_window(ew+i,3)=forcast_plot_c_obs(1,i)'
forcast_open_current_window(ew+i,4)=forcast_plot_i_obs(1,i)'
forcast_open_current_window(ew+i,6)=forcast_plot_r_obs(1,i)'
forcast_open_current_window(ew+i,7)=forcast_plot_E_obs(1,i)'
forcast_open_current_window(ew+i,8)=forcast_plot_y_obs(1,i)'
end

figure
subplot(4,2,1)
plot(forcast_open_current_window(:,1),'--','LineWidth',2); hold on
plot(datafull(1:ew+hmax,1),'k','LineWidth',2)%(:,1),'k','LineWidth',2)
title('Inflation')
legend('Forecasted value','Actual data' ,'Location','Southwest')
legend('Boxoff')

subplot(4,2,2)
plot(forcast_open_current_window(:,2),'--','LineWidth',2); hold on
plot(datafull(1:ew+12,2),'k','LineWidth',2)
%plot(data_current_window_plot(:,2),'k','LineWidth',2)
% axis([ew-hmax ew+4 -5 5])
title('Wage')

subplot(4,2,3)
plot(forcast_open_current_window(:,3),'--','LineWidth',2); hold on
plot(datafull(1:ew+hmax,3),'k','LineWidth',2)
%plot(data_current_window_plot(:,3),'k','LineWidth',2)
% axis([ew-hmax ew+4 -4 4])
title('Consumption')

subplot(4,2,4)
plot(forcast_open_current_window(:,4),'--','LineWidth',2); hold on
plot(datafull(1:ew+hmax,4),'k','LineWidth',2)
%plot(data_current_window_plot(:,4),'k','LineWidth',2)
% axis([ew-hmax ew+4 -10 6])
title('Investment')

subplot(4,2,5)
plot(forcast_open_current_window(:,6),'--','LineWidth',2); hold on
plot(datafull(1:ew+hmax,6),'k','LineWidth',2)
%plot(data_current_window_plot(:,6),'k','LineWidth',2)
% axis([ew-hmax ew+4  2 8])
title('Interest rate')

subplot(4,2,6)
plot(forcast_open_current_window(:,7),'--','LineWidth',2); hold on
plot(datafull(1:ew+hmax,7),'k','LineWidth',2)
%plot(data_current_window_plot(:,7),'k','LineWidth',2)
% axis([ew-hmax ew+4 -3 3])
title('Employment')

subplot(4,2,7)
plot(forcast_open_current_window(:,8),'--','LineWidth',2); hold on
plot(datafull(1:ew+hmax,8),'k','LineWidth',2)
%plot(data_current_window_plot(:,8),'k','LineWidth',2)
% axis([ew-hmax ew+4 -1 3.3])
title('Output')

% Saving the current figure of forecasted values to check how predicted values behave
print( '-depsc', sprintf('ForecastOpen%d.eps', bw)) 

% going to next window
bw=bw+1;
ew=ew+1;

end




