////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////
// ALLV Model - JEDC spec, April 2006
// Written by Stefan Lasen, Jan 2010
// Modified by Malin Adolfson, Jan 2011
// Parameter values: with UIP-modification, instrument rule without policy break (posterior median, see Table 2 Adolfson and Lind,2009)
// modifiedmodel by excluding goverment sector to fit the Australian data by Phuong Nguyen, March 2018
// This version, Phuong will estimate model with 13 structural shock, in which it has 2 white noice process:
// Monetary policy shock
// Inflation target shock
// Thus, I estimate 50 params. for open economy DSGE model
// Note that: there are 14 obs. variables and 16 structural shocks 
// (3 foreign economy shocks are pre-estimated)
///////////////////////////////////////////////////////////////////////////


var 
pid_hat,        % [01] Domestic price
pimc_hat,       % [02] imported comsumption price
pimi_hat,       % [03]imported investment price
pic_hat,        % [04] consumption price
pix_hat,        % [05] exporting price
w_hat,          % [06] wage
c_hat,          % [07] consumption
i_hat,          % [08] investment
mult_hat,       % [09] lagrangian multiplier
Pkprime_hat,    % [10] price of bond (see appendix 7.3)
deltaS_hat,     % [11] growth of nominal exchange rate
H_hat,          % [12] Working hours
kbar_hat,       % [13] utilized capital
k_hat,          % [14] capital
q_hat,          % [15] cash holding
mbar_hat,       % [16] financial asset 
mu_hat,         % [17] money growth
a_hat,          % [18] net foreign asset
gammacd_hat,    % [19] relative price between consumption price to aggregate price
gammaid_hat,    % [20] relative price between investment price to aggregate price
gammamcd_hat,   % [21] relative price between imported consumption price to aggregate price  
gammamid_hat,   % [22] relative price between imported investment price to aggregate price
gammaf_hat,     % [23] relative price between aggregate domestic price and aggregate foreign price
gammaxstar_hat, % [24] relative price between the domestically produced goods and the foreign goods price
x_hat,          % [25] exchange rate
mc_hat,         % [26] marginal cost of domestic firm
mcmc_hat,       % [27] marginal cost of imported consumption firm
mcmi_hat,       % [28] marginal cost of imported investment firm
mcx_hat,        % [29] marginal cost of exporting firm
R_hat,          % [30] interest rate
Rf_hat,         % [31] the gross effective nominal interest rate    
eps_hat,        % [32] stationary technology shock
muz_hat,        % [33] unit root technology shock
zetac_hat,      % [34] consumption preference shock
zetah_hat,      % [35] labor supply shock
lambdaf_hat,    % [36] markup domestic
etamc_hat,      % [37] markup imported consumption
etami_hat,      % [38] markup imported investment
phitilde_hat,   % [39] risk premium
upsilon_hat,    % [40] investment specific technology 
tauk_hat,       % [41] capital income tax
tauy_hat,       % [42] income tax
tauc_hat,       % [43] consumption tax
tauw_hat,       % [44] wage tax
g_hat,          % [45] government spending
epsR_hat,       % [46] policy interest rate shock
pistar_hat,     % [47] foreign inflation
ystar_hat,      % [48] foreign output
Rstar_hat,      % [49] foreign interest rate
y_hat,          % [50] domestic output
rk_hat,         % [51] the scaled equilibrium reantal rate of capital
lambdax_hat,    % [52] markup exporting firm
zetatilde_hat,  % [53] asymmetric technology
piT_hat,        % [54] inflation target
data_pid,       % [55] obs. domestic infaltion      
data_wp,        % [56] obs. domestic real wage
data_c,         % [57] obs. domestic real consumption
data_i,         % [58] obs. domestic real investment
data_R,         % [59] obs. policy interest rate
data_y,         % [60] obs. domestic real output
data_x,         % [61] obs. domestic real export
data_m,         % [62] obs. domestic real import
data_pic,       % [63] obs. domestic consumption price
data_ystar,     % [64] obs. foreign output
data_pistar,    % [65] obs. foreign inflation
data_Rstar,     % [66] obs. foreign interest rate
E_t;            % [67] obs. domestic employment 


varexo
eps_muzhat,             % [01] standard deviation of non-stationary tech.shock
eps_epshat,             % [02] standard deviation of stationary tech shock
eps_etamchat,           % [03] standard deviation of markup imported cons. shock
eps_etamihat,           % [04] standard deviation of markup imported invs. shock
eps_lambdafhat,         % [05] standard deviation of markup domestic shock
eps_upsilonhat,         % [06] standard deviation of investment specific tech. shock
eps_phitildehat,        % [07] standard deviation of risk primium shock
eps_zetachat,           % [08] standard deviation of consumption preference shock
eps_zetahhat,           % [09] standard deviation of labor supply shock
eps_zetatildehat,       % [10] standard deviation of asymmetric technology shock
eps_lambdaxhat ,        % [11] standard deviation of markup exporting shock
eps_epsRhat,            % [12] standard deviation of monetary policy shock
eps_piThat,             % [13] standard deviation of inflation target shock
eps_pistarhat,          % [14] standard deviation of foreign inflation shock is estimated exogenously
eps_ystarhat,           % [15] standard deviation of foreign output shock is estimated exogenously
eps_Rstarhat,           % [16] standard deviation of foreign interest rate is estimated exogenously
eps_taukhat,            % [17] standard deviation of gover. shock will be shutted down
eps_tauyhat,            % [18] standard deviation of gover. shock will be shutted down
eps_tauchat,            % [19] standard deviation of gover. shock will be shutted down
eps_tauwhat,            % [20] standard deviation of gover. shock will be shutted down
eps_ghat,               % [21] standard deviation of gover. shock will be shutted down
eps_zetaqhat,           % [22] standard deviation of  household money demand shock (excluded)
eps_nuhat,              % [23] standard deviation of  firm money demand shock (excluded)
eps_muhat;              % [24] standard deviation of money supply shock (excluded)   

parameters  
Al,                         % [] param. of working hours in houshold's utility function
Aq,                         % [] cash to money ratio in houshold's utility function
b,                          % [] consumption habit formation
beta,                       % [] discount rate	
cbar,                       % [] steady state aggregate cons defined in A.28 page 47	
cdbar,                      % [] steady state dometic cons
cdfbar,                     % [] steady state exported cons
csbar,                      % []
D1,                         % [] defined in (A27) page 47 in working paper version
D2,                         % [] defined in (A27) page 47 in working paper version
D3,                         % [] defined in (A27) page 47 in working paper version
D4,                         % [] defined in (A27) page 47 in working paper version
delta,                      % [] appreciated rate in capital	
epspolicy,                  % []
epsz,                       % []
etac,                       % [] param. in the aggregate resource constraint (B.11) on page 51
etaf,                       % [] param. in the aggregate resource constraint (B.11) on page 51
etai,                       % [] param. in the aggregate resource constraint (B.11) on page 51
etamc,                      % [] 
etami,                      % []
gammacd,                    % [] steady state relative price defined in A.9 page 43
gammacmc,                   % [] steady state relative price defined in A.10 page 43
gammadc,                    % []	
gammadi,                    % []	
gammaf,                     % []
gammaid,                    % [] steady state relative price defined in A.11 page 43
gammaimi,                   % [] steady state relative price defined in A.12  page 43	
gammamcd,                   % []	
gammamid,                   % []	
gammapi1,                   % []	
gammapi2,                   % []	
gammapi3,                   % []	
gammaq1,                    % []
gammaq2,                    % []	
gammaq3,                    % []	
gammax,                     % []
gammay1,                    % []	
gammay2,                    % []	
gammay3,                    % []	
gbar,                       % [] steady state government expenditure defined in A.30 page 47
Hbar,                       % [] steady state hour worked defined in A.28 page 47
ibar,                       % [] steady state aggregate investment defined in A.22 page 45
idbar,                      % [] steady state domestic investment
idfbar,                     % [] steady state exported investment
isbar,                      % []
kbar,                       % [] steady state capital defined above A.22 page 45
koverH,                     % [] steady state of ratio capital over hours worked
lambdaf,                    % [] markup domestic shock param.
lambdaw,                    % []	
mbar,                       % [] steady state money 
mcbar,                      % [] steady state domestic marginal cost
mu,                         % [] steady stated money growth
muz,                        % [] steady state technology growth
nubar,                      % [] share of wage finance in advance
omegac,                     % [] share of imported consumption
omegai,                     % [] sjare of imported investment
phi,                        % [] steady state risk premium defined in A.20 page 45
phitilde,                   % [] risk premium params in UIP (2.59) page 16
phiz,                       % [] steady state value defined in A.23 page 46
piebar,                     % [] steady state inflation defined in A.3 page 42
piecbar,                    % [] steady state CPI inflation 
Pii1,                       % []
Pii2,                       % []
Pii3,                       % []
Piim,                       % []
Piimc,                      % []
PiimcPc,                    % [] steady state profit of imported cons. firm	
Piimi,                      % [] steady state profit of imported invs. firm
PiimiPi,                    % []	
PiiTot,                     % []
Pkprime,                    % [] price of capital
qbar,                       % [] steady state asset  defined above A.32 page 48
ratioc,                 	% [] steady state ratio of aggregate consumption over output
ratiog,                     % [] steady state ratio of govern. expenditure over output
ratioi,                     % [] steady state ratio of aggregate investment over output
ratiox,                     % [] steady state ratio of export over output
ratioz,                 	% [] steady state ratio of imported over output
Rbar,                       % [] steady state interest rate defined A.2 page 42
Rfbar,                      % [] steady state efficient interest rate defined in A.17 page 44
rhoeps,                     % [] persistent param. in
rhoetamc,                   % [] persistent param. in	
rhoetami,                   % [] persistent param. in	
rhoiota,                    % [] persistent param. in
rholambda,                  % [] persistent param. in
rhomuz,                     % [] persistent param. in
rhonu,                      % [] persistent param. in
rhophitilde,                % [] persistent param. in risk premium shock process	
rhoR,                       % [] persistent param. in interest rate shock process
rhozetac,                   % [] persistent param. in cons. preference shock process
rhozetah,                   % [] persistent param. in labor supply shock process
rhozetaq,                   % [] persistent param. in household's money demand shock process (but exclude later)
rkbar,                      % [] steady state capital rental rate defined in A.16 page 44
sharek,                     % [] share of capital in production function
sigmaa,                     % [] curvature parameter ralated to consumption in utility function 
sigmal,                     % [] curvature parameter ralated to labor supply in utility function 
sigmaq,                     % [] curvature parameter related to money demand in utility function 
SS,                         % [] investment adjusted cost
tauc,                       % [] steady state consumption tax
tauk,                       % [] steady state capital income tax
tauw,                       % [] steady state wage tax
tauy,                       % [] steady state income tax
wbar,                       % [] steady state wage
xbar,                       % [] steady state real exchange rate defined in A.26 page 46
xid,                        % [] Calvo domestic price
ximc,                       % [] Calvo imported cons. price
ximi,                       % [] Calvo imported invs. price
xiw,                        % [] Calvo wage
ybar,                       % [] steady state domestic output defined in A.29 page 47
ybar1,                      % []
ybar2,                      % []
ybar3,                      % []
zbar,                       % []
bw,                         % [] param. in wage equation in (B.5) on page 50 working paper version
eta0,                       % [] param. in wage equation in (B.5) on page 50 working paper version
eta1,                       % [] param. in wage equation in (B.5) on page 50 working paper version
eta2,                       % [] param. in wage equation in (B.5) on page 50 working paper version
eta3,                       % [] param. in wage equation in (B.5) on page 50 working paper version
eta4,                       % [] param. in wage equation in (B.5) on page 50 working paper version
eta5,                       % [] param. in wage equation in (B.5) on page 50 working paper version
eta6,                       % [] param. in wage equation in (B.5) on page 50 working paper version
eta7,                       % [] param. in wage equation in (B.5) on page 50 working paper version
eta8,                       % [] param. in wage equation in (B.5) on page 50 working paper version
eta9,                       % [] param. in wage equation in (B.5) on page 50 working paper version
eta10,                      % [] param. in wage equation in (B.5) on page 50 working paper version
eta11,                      % [] param. in wage equation in (B.5) on page 50 working paper version
eta12,                      % []
eta13,                      % []
eta14,                      % []
eta3bar,                    % []
rhotauk,                    % [] persistent param. in capital income tax shock process
rhotauy,                    % [] persistent param. in income tax shock process
rhotauc,                    % [] persistent param. in cons income tax shock process
rhotauw,                    % [] persistent param. in wage income tax shock process
rhog,                       % [] persistent param. in govern. expenditure shock process
rhoepsR,                    % [] persistent param. in monetary shock process
rhopistar,                  % [] persistent param. in foreign inflation shock process
rhoystar,                   % [] persistent param. in foreign output shock process
rhoRstar,                   % [] persistent param. in foreign interest rate shock process
cmbar,                      % [] steady state imported cons
imbar,                      % [] steady state imported invs
rholambdax,                 % [] persistent param. in markup exporting firm shock process
rhozetatilde,               % [] persistent param. in markup in asymmetric tech. shock process
xix,                        % [] Calvo exporting
kappaw,                     % [] indexation wage
kappad,                     % [] indexation domestic price
rhopietarget,               % [] persistent param. in inflation target shock process
kappax,                     % [] indexation exporting
rdeltapi ,                  % [] Taylor rule, change in inflation rate response
rpie ,                      % [] Taylor rule, inflation rate response
rx ,                        % [] Taylor rule, real exchange rate response
ry ,                        % [] Taylor rule, real output response
rdeltay,                    % [] Taylor rule, real output growth response
kappamc ,                   % [] indexation imported cons.
kappami,                    % [] Indexation imported invs.
xie,                        % [] Calvo employment
phitildes,                  % [] Modified UIP param.
%%%%%%%%%%%%%%%%%%%% Foreign economy VAR parameters%%%%%%%%%%%%%%%%%%%%%%%%
ForLag111 ,ForLag112 ,ForLag113 ,ForLag121 ,ForLag122 ,ForLag123 ,ForLag131 ,ForLag132 ,ForLag133 ,
ForLag211 ,ForLag212 ,ForLag213 ,ForLag221 ,ForLag222 ,ForLag223 ,ForLag231 ,ForLag232 ,ForLag233 ,
ForLag311 ,ForLag312 ,ForLag313 ,ForLag321 ,ForLag322 ,ForLag323 ,ForLag331 ,ForLag332 ,ForLag333 ,
ForLag411 ,ForLag412 ,ForLag413 ,ForLag421 ,ForLag422 ,ForLag423 ,ForLag431 ,ForLag432 ,ForLag433,
ForShock11 ,ForShock12 ,ForShock13 ,ForShock21 ,ForShock22 ,ForShock23 ,ForShock31 ,ForShock32 ,ForShock33,
FisLag111 ,FisLag112 ,FisLag113 ,FisLag121 ,FisLag122 ,FisLag123 ,FisLag131 ,FisLag132 ,FisLag133 ,
FisLag211 ,FisLag212 ,FisLag213 ,FisLag221 ,FisLag222 ,FisLag223 ,FisLag231 ,FisLag232 ,FisLag233 ,
FisShock11, FisShock12, FisShock13, FisShock14, FisShock15, FisShock21, FisShock22, FisShock23, FisShock24,
FisShock25,FisShock31, FisShock32, FisShock33, FisShock34, FisShock35, FisShock41, FisShock42, FisShock43,
FisShock44, FisShock45,FisShock51, FisShock52, FisShock53, FisShock54, FisShock55,epstauk, epstauw,lambdamc,
lambdami;

///////////////////////////////////////////////////////////////////////////
//          Assigning the parameter their Bayesian estimates.
///////////////////////////////////////////////////////////////////////////

phitildes       =	    0       ;   % Phuong exclude this param 0.606  phitildes % to use the trational UIP form ;
xiw             =	    0.765	;
xid             =	    0.825	;
ximc            =	    0.900	;
ximi            =	    0.939	;
xix             =	    0.874	;
xie             =       0.7975  ;    % change made by Gerret from 0 to 0.7975, 27.06.2017
kappad          =	    0.227	;
kappaw          =	    0.323	;
kappamc         =       0.2     ;    
kappami         =       0.3     ;    
kappax          =       0.3     ;   
SS              =	    8.584	;
b               =	    0.679	;
lambdaf         =	    1.195	;
etai            =	    2.715	;
etaf            =	    1.531	;
lambdamc        =	    1.584	;
lambdami        =	    1.134	;
muz             =	    1.0041	;
phitilde        =	    0.050	;
rhomuz          =	    0.845	;
rhoeps          =	    0.925	;
rhoiota         =	    0.694	;
rhophitilde     =	    0.684	;
rhozetac        =	    0.657	;
rhozetah        =	    0.270	;
rhozetatilde	=	    0.964	;
rhoR            =	    0.913	;
rpie            =	    1.674	;
rdeltapi        =	    0.098	;
rx              =	    -0.016	;
ry              =	    0.125	;
rdeltay         =	    0.178	;
muz             =	1.0041      ;  % technology

///////////////////////////////////////////////////////////////////////////
//                    Calibrating params 
///////////////////////////////////////////////////////////////////////////

sigmaq      =	10.62	;% real cash holding elasticity calibrated based on
                         % Adolfson (2007): 10.62                         
sigmaa      =	0.049	;% capital utilisation cost,no variable capital utilization, other literatures, such as
                         % CEE (2005): 0.01
                         % Altig (2005): 11.42
                         % Adolfson (2007): 10^6 if the model is no variable capital utilization. They also calibrate 0.049
                         % Jaaskela and Nimark (2011): 0.049
nubar       =	1;   	 % share of wage in advance is calibrated based on literatures
                         % Adolfson (2007): 1
                         % Jaaskela and Nimark (2011): 0.95
etac        =	0.885;   % elasticity of substition  btw domestic goods and  foreign consumption goods
                         % Adoflson calibrate it as  5, but Phuong modify it as 0.885 as the average of 4 lituratures
                         % estimation of etac in other literatures, such as 
                         % Justininano and Preston (2010): 0.86; 

%% set all markup shocks are the White Noise as Adofson..(2007)
rholambdax	=	0	;    % persistent parameter of the markup export shock
rhoetamc	=	0	;    % persistent parameter of the markup import in consumption goods shock
rhoetami	=	0	;    % persistent parameter of the markup import in investment goods shock
rholambda	=	0	;    % persistent parameter of the  domestic markup shock
rhoepsR     =	0	;    % the persistent parameter in monetary policy shock process
%.........................................................................

% Goverment parameters....................................................
rdeltax     =	0	;    % govern. pram
rhotauk     =	0   ;    % govern. parm Phuong 28,6 0.9	;
rhotauw     =	0   ;    % govern. pram Phuong 28.6 0.9	;
epstauk     =	0   ;    % govern. pram Phuong 28.6 1	;
epstauw     =	0   ;    % govern. pram Phuong 28.6 1	;
tauk        =	0	;    % gover. Param, it is set as o then deriving the form as Altig (2005)and CEE(2005)
tauw        =	0   ;    % 0.3	govern. Parma Phuong 28.6;
%.........................................................................
mu          =	1.01;    % Money growth rate,pg modified
beta        =	0.999;   % Pg bases on Justiniano & Preston (2010). This calibrated param. is not so diff
                         % such as, Jaaskela and Nimark (2011): 0.999
                         % Daniel, Smith and Hall (2016):0.9996
                         % Li & Spencer (2016): 0.9868
sigmal      =	1	;    % labor suppy elasticity,This calibration is common in literatures, such as
                         % CEE(2005);Gali and Monacelli (2005); Adoflson..(2007), and
                         % in AUS lituratures, such as Jaaskela and Nimark (2011),Daniel, Smith and Hall (2016)
                         % Justiniano & Preston (2010)estimated the inverse elastictiy of labor suppply of 1.12
                         % but poorly identified in DSGE model with a big confident interval
                         % it implies that the elasticity of labor supply is 1/1.12 equals to 0.89
                         % not so diffent from 1

delta       =	0.013;   % 0.0175	;// depreciation rate, png modify according to AUS
                         % Jaaskela and Nimark (2011):0.013
                         % Daniel, Smith and Hall (2016): 0.0175, which is around the average value of this param. in Aus national accounts
sharek      =	0.25;    % Justiano & Preston (2010)
lambdaw     =	1.05;    % wage markup, no modification is needed 
                         % CEE(2005); Adofson..(2007)
ratiog      =	0;       % govern. pram pg modify 28,60.3	;
omegac      =	0.2;     % Justiano & Preston (2010)
omegai      =	0.5	;    % 0.5 is standard // share of import in investment, Jaaskela and Nimark (2011):0.5
tauy        =	0;       % govern. pram 0.3	; //Pg 28.6
tauc        =	0;       % govern. pram 0.24; //Pg 28.6
Al          =	6.5	;    % labor disutility param., Pg modify based on literatures, such as
                         % Adoflson..(2007): 6.5
Aq          =	0.1	;    % Cash in Utility function parm.,
                         % Adoflson..(2007): 0.1
rhopietarget	=	0.975;    % Persistent parameter in inflation targeting
                              % Smet & Woulter (2003):1
                              % Adoflson..(2007): 0.975
gammaf      =	1	;
gammapi1	=	0	;
gammaq1     =	0	;
gammaq3     =	0	;
gammay1     =	0	;         % no role
rhonu       =	0	;         % no role
rhozetaq	=	0	;         % no role
epsmdfi     =	0	;         % no role
epsmdhh     =	0	;         % no role



//m-file with the VAR-par
ForFisEstRes_Pmod; 
//Params to Foreign VAR
//Lag 1
ForLag111 = A1_for(1,1);
ForLag112 = A1_for(1,2);
ForLag113 = A1_for(1,3);
ForLag121 = A1_for(2,1);
ForLag122 = A1_for(2,2);
ForLag123 = A1_for(2,3);
ForLag131 = A1_for(3,1);
ForLag132 = A1_for(3,2);
ForLag133 = A1_for(3,3);
//Lag 2
ForLag211 = A2_for(1,1);
ForLag212 = A2_for(1,2);
ForLag213 = A2_for(1,3);
ForLag221 = A2_for(2,1);
ForLag222 = A2_for(2,2);
ForLag223 = A2_for(2,3);
ForLag231 = A2_for(3,1);
ForLag232 = A2_for(3,2);
ForLag233 = A2_for(3,3);
//Lag 3
ForLag311 = A3_for(1,1);
ForLag312 = A3_for(1,2);
ForLag313 = A3_for(1,3);
ForLag321 = A3_for(2,1);
ForLag322 = A3_for(2,2);
ForLag323 = A3_for(2,3);
ForLag331 = A3_for(3,1);
ForLag332 = A3_for(3,2);
ForLag333 = A3_for(3,3);
//Lag 4
ForLag411 = A4_for(1,1);
ForLag412 = A4_for(1,2);
ForLag413 = A4_for(1,3);
ForLag421 = A4_for(2,1);
ForLag422 = A4_for(2,2);
ForLag423 = A4_for(2,3);
ForLag431 = A4_for(3,1);
ForLag432 = A4_for(3,2);
ForLag433 = A4_for(3,3);
//For Shock
ForShock11 = B0_for(1,1);
ForShock12 = B0_for(1,2);
ForShock13 = B0_for(1,3);
ForShock21 = B0_for(2,1);
ForShock22 = B0_for(2,2);
ForShock23 = B0_for(2,3);
ForShock31 = B0_for(3,1);
ForShock32 = B0_for(3,2);
ForShock33 = B0_for(3,3);

// Pg 27.06
//Params to Fiscal VAR
//Lag 1
FisLag111 = A1_fis(1,1);
FisLag112 = A1_fis(1,2);
FisLag113 = A1_fis(1,3);
FisLag121 = A1_fis(2,1);
FisLag122 = A1_fis(2,2);
FisLag123 = A1_fis(2,3);
FisLag131 = A1_fis(3,1);
FisLag132 = A1_fis(3,2);
FisLag133 = A1_fis(3,3);
//Lag 2
FisLag211 = A2_fis(1,1);
FisLag212 = A2_fis(1,2);
FisLag213 = A2_fis(1,3);
FisLag221 = A2_fis(2,1);
FisLag222 = A2_fis(2,2);
FisLag223 = A2_fis(2,3);
FisLag231 = A2_fis(3,1);
FisLag232 = A2_fis(3,2);
FisLag233 = A2_fis(3,3);
//Fis Shock
FisShock11 = B0_fis(1,1);     //tauk
FisShock12 = B0_fis(1,2);     //tauy
FisShock13 = B0_fis(1,3);     //tauc
FisShock14 = B0_fis(1,4);     //tauw
FisShock15 = B0_fis(1,5);     //g_gap
FisShock21 = B0_fis(2,1);
FisShock22 = B0_fis(2,2);
FisShock23 = B0_fis(2,3);
FisShock24 = B0_fis(2,4);
FisShock25 = B0_fis(2,5);
FisShock31 = B0_fis(3,1);
FisShock32 = B0_fis(3,2);
FisShock33 = B0_fis(3,3);
FisShock34 = B0_fis(3,4);
FisShock35 = B0_fis(3,5);
FisShock41 = B0_fis(4,1);
FisShock42 = B0_fis(4,2);
FisShock43 = B0_fis(4,3);
FisShock44 = B0_fis(4,4);
FisShock45 = B0_fis(4,5);
FisShock51 = B0_fis(5,1);
FisShock52 = B0_fis(5,2);
FisShock53 = B0_fis(5,3);
FisShock54 = B0_fis(5,4);
FisShock55 = B0_fis(5,5);
///////////////////////////////////////////////////////////////////////////

model(linear);

///////////////////////////////////////////////////////////////////////////
//                           I: ENDOGENOUS VARIABLES                     //
///////////////////////////////////////////////////////////////////////////

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                              2.1 FIRM SECTOR                          %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% [01] production function      
y_hat = lambdaf*((1-sharek)*H_hat + sharek*k_hat - sharek*muz_hat + eps_hat ) ;


% [02] the New Keyesian Phillip Curve (NKPC) of domestic firm
pid_hat = piT_hat + (beta/(1+kappad*beta))*(pid_hat(+1) - rhopietarget*piT_hat) +  (kappad/(1+kappad*beta))*(pid_hat(-1) - piT_hat) 
            + (((1-xid)*(1-beta*xid))/(xid*(1+kappad*beta)))*( mc_hat) + lambdaf_hat   
            -(kappad*beta*(1-rhopietarget)/(1+kappad*beta))*piT_hat ;

% [03] the New Keyesian Phillip Curve (NKPC) of imported consumption firm
pimc_hat = piT_hat + (beta/(1+kappamc*beta))*(pimc_hat(+1) - rhopietarget*piT_hat) +  (kappamc/(1+kappamc*beta))*(pimc_hat(-1) - piT_hat) 
            + (((1-ximc)*(1-beta*ximc))/(ximc*(1+kappamc*beta)))*( mcmc_hat )+ etamc_hat
            -(kappamc*beta*(1-rhopietarget)/(1+kappamc*beta))*piT_hat ;

% [04] the New Keyesian Phillip Curve (NKPC) of imported investment firm
pimi_hat = piT_hat + (beta/(1+kappami*beta))*(pimi_hat(+1) - rhopietarget*piT_hat) +  (kappami/(1+kappami*beta))*(pimi_hat(-1) - piT_hat) 
            + (((1-ximi)*(1-beta*ximi))/(ximi*(1+kappami*beta)))*( mcmi_hat)  + etami_hat  
            -(kappami*beta*(1-rhopietarget)/(1+kappami*beta))*piT_hat ;

% [05] the New Keyesian Phillip Curve (NKPC) of exporting firm
pix_hat = piT_hat + (beta/(1+kappax*beta))*(pix_hat(+1) - rhopietarget*piT_hat) +  (kappax/(1+kappax*beta))*(pix_hat(-1) - piT_hat) 
            + (((1-xix)*(1-beta*xix))/(xix*(1+kappax*beta)))*( mcx_hat)  + lambdax_hat  
            -(kappax*beta*(1-rhopietarget)/(1+kappax*beta))*piT_hat ; 

% [06] the real marginal cost of domestic firm
mc_hat = sharek*(muz_hat + H_hat - k_hat) + w_hat + Rf_hat - eps_hat;

% [07] the real marginal cost of imported consumption firm
mcmc_hat = - mcx_hat - gammaxstar_hat - gammamcd_hat;

% [08] the real marginal cost of imported investment firm
mcmi_hat = - mcx_hat - gammaxstar_hat - gammamid_hat;

% [09] the real marginal cost of exporting firm
mcx_hat = mcx_hat(-1) + pid_hat - pix_hat - deltaS_hat;

% [10] the gross effective nominal interest rate                                     
Rf_hat = (nubar*Rbar/(nubar*Rbar+1-nubar))*R_hat(-1);

% [11] the scaled equilibrium reantal rate of capital
rk_hat = muz_hat + w_hat + Rf_hat + H_hat - k_hat;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                          2.2 HOUSEHOLDS SECTOR                        %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% [12] law of motion for the capital stock  in 2.46                               
kbar_hat = (1-delta)*(1/muz)*kbar_hat(-1) - (1-delta)*(1/muz)*muz_hat + (1-(1-delta)*(1/muz))*upsilon_hat + (1-(1-delta)*(1/muz))*i_hat;

% [13] exchange rate
x_hat =  -omegac*(( (1-omegac)*(((lambdamc/(lambdamc-1))-1)/(lambdamc/(lambdamc-1)))^(1-etac) + omegac )^(1/(1-etac)))^(-(1-etac))*gammamcd_hat - gammaxstar_hat - mcx_hat;
                                
% [14] consumption in 2.51                
c_hat = -(1/(muz^2 + beta*b^2))*(-b*beta*muz*c_hat(+1) -b*muz*c_hat(-1) + b*muz*(muz_hat - beta*muz_hat(+1)) 
        +(muz-b*beta)*(muz-b)*mult_hat + (tauc/(1+tauc))*(muz-b*beta)*(muz-b)*tauc_hat + (muz-b*beta)*(muz-b)*gammacd_hat)
        -zetac_hat ;

% [15] F.O.C with respect to m(t+1) in 2.52
mult_hat = mult_hat(+1) - muz_hat(+1) + (1/mu)*(mu - beta*tauk)*R_hat - pid_hat(+1) + (1/mu)*(tauk/(1-tauk))*(beta - mu)*tauk_hat(+1);
 

% [16] log-linearizing the F.O.C w.r.t the utilised capital in 2.54
Pkprime_hat = -mult_hat - muz_hat(+1) + mult_hat(+1) + (beta*(1-delta)/muz)*Pkprime_hat(+1) - (tauk/(1-tauk))*((muz-beta*(1-delta))/muz)*tauk_hat(+1) 
              + ((muz-beta*(1-delta))/muz)*rk_hat(+1);

% [17] investment in 2.55 
i_hat = (1/((SS*muz^2)*(1+beta)))*((SS*muz^2)*(i_hat(-1) + beta*i_hat(+1) - muz_hat + beta*muz_hat(+1)) + Pkprime_hat +  upsilon_hat - gammaid_hat );

% [18] the utilisation rate u(t)=K(t)/KBar(t) in 2.56
k_hat = kbar_hat(-1) + (1/sigmaa)*rk_hat - (1/sigmaa)*(tauk/(1-tauk))*tauk_hat; 

% [19] cash balance holding q(t) in 2.57
q_hat = (1/sigmaq)*((tauk/(1-tauk))*tauk_hat - mult_hat - (Rbar/(Rbar-1))*R_hat(-1));

% [20] The modified UIP condition in 2.59
(1-phitildes)*deltaS_hat(+1) - phitildes*deltaS_hat - (R_hat - Rstar_hat) - phitilde*a_hat + phitilde_hat = 0;
                             
% [21] Money growth
mbar_hat(-1) = mbar_hat + pid_hat + muz_hat - mu_hat;

% [22] wage setting
w_hat = -(1/(sigmal*lambdaw - bw*(1+beta*(xiw^2))))*((((lambdaw*sigmal - (1-lambdaw))/((1-beta*xiw)*(1-xiw)))*xiw)*w_hat(-1) 
+ (((lambdaw*sigmal - (1-lambdaw))/((1-beta*xiw)*(1-xiw)))*beta*xiw)*w_hat(+1) 
+ (-((lambdaw*sigmal - (1-lambdaw))/((1-beta*xiw)*(1-xiw)))*xiw)*pid_hat 
+ (((lambdaw*sigmal - (1-lambdaw))/((1-beta*xiw)*(1-xiw)))*beta*xiw)*pid_hat(+1) 
+ (((lambdaw*sigmal - (1-lambdaw))/((1-beta*xiw)*(1-xiw)))*kappaw*xiw)*pic_hat(-1) 
+ (-((lambdaw*sigmal - (1-lambdaw))/((1-beta*xiw)*(1-xiw)))*beta*kappaw*xiw)*pic_hat 
- ((-((lambdaw*sigmal - (1-lambdaw))/((1-beta*xiw)*(1-xiw)))*xiw) 
+ rhopietarget*(((lambdaw*sigmal - (1-lambdaw))/((1-beta*xiw)*(1-xiw)))*beta*xiw) 
+ (((lambdaw*sigmal - (1-lambdaw))/((1-beta*xiw)*(1-xiw)))*kappaw*xiw) 
+ rhopietarget*(-((lambdaw*sigmal - (1-lambdaw))/((1-beta*xiw)*(1-xiw)))*beta*kappaw*xiw))*piT_hat
+ (1-lambdaw)*mult_hat 
+ (-(1-lambdaw)*sigmal)*H_hat 
+ (-(1-lambdaw)*(tauy/(1-tauy)))*tauy_hat 
+ (-(1-lambdaw)*(tauw/(1+tauw)))*tauw_hat) 
- zetah_hat;   

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                             2.3 GOVERNMENT SECTOR                     %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

// shutting down government sector
% [23] capital tax
tauk_hat=0;

% [24] wage tax
tauw_hat=0;

% [25] income tax
tauy_hat=0;

% [26] consumption tax
tauc_hat=0;

% [27] government spending
g_hat=0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                     2.4. THE RELATIVE PRICE                           %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% [28] relative price between consumption price to aggregate price
gammacd_hat = omegac*((( (1-omegac)*(((lambdamc/(lambdamc-1))-1)/(lambdamc/(lambdamc-1)))^(1-etac) + omegac )^(1/(1-etac)))^(-(1-etac)))*gammamcd_hat;

% [29] relative price between investment price to aggregate price
gammaid_hat = omegai*((( (1-omegai)*(((lambdami/(lambdami-1))-1)/(lambdami/(lambdami-1)))^(1-etai) + omegai )^(1/(1-etai)))^(-(1-etai)))*gammamid_hat;

% [30] relative price between imported consumption price to aggregate price
gammamcd_hat = gammamcd_hat(-1) + pimc_hat - pid_hat;

% [31] relative price between imported investment price to aggregate price
gammamid_hat = gammamid_hat(-1) + pimi_hat - pid_hat;

% [32] relative price between aggregate domestic price and aggregate foreign price
gammaf_hat = mcx_hat + gammaxstar_hat;

% [33] relative price between the domestically produced goods and the foreign goods price
gammaxstar_hat = gammaxstar_hat(-1) + pix_hat - pistar_hat;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                         2.5. CENTRAL BANK                             %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% [34]Policy rule
R_hat = rhoR*R_hat(-1) + (1-rhoR)*(piT_hat  + rpie*(pic_hat(-1) - piT_hat) + ry*y_hat(-1) + rx*x_hat(-1) ) + rdeltapi*(pic_hat-pic_hat(-1)) 
        +rdeltay*(y_hat-y_hat(-1))  + epsR_hat; 

% [35] consumption price corresponding to (2.76)
pic_hat = ((1-omegac)*((( (1-omegac) + omegac*((lambdamc/(lambdamc-1))/((lambdamc/(lambdamc-1))-1))^(1-etac) )^(1/(1-etac))))^(-(1-etac)))*pid_hat  +  ((omegac)*((( (1-omegac)*(((lambdamc/(lambdamc-1))-1)/(lambdamc/(lambdamc-1)))^(1-etac) + omegac )^(1/(1-etac))))^(-(1-etac)))*pimc_hat;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                  2.6. MARKET CLEARING CONDITIONS                      %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% [36] The aggregate resource constraint
 H_hat*(lambdaf*(1-sharek)) = ((1-omegac)*((( (1-omegac) + omegac*((lambdamc/(lambdamc-1))/((lambdamc/(lambdamc-1))-1))^(1-etac) )^(1/(1-etac)))^etac)*(cbar/ybar)*(c_hat + etac*gammacd_hat) 
                                    +(1-omegai)*((( (1-omegai) + omegai*((lambdami/(lambdami-1))/((lambdami/(lambdami-1))-1))^(1-etai) )^(1/(1-etai)))^etai)*(ibar/ybar)*(i_hat + etai*gammaid_hat)
                                    +(gbar/ybar)*g_hat
                                    +((gammaf^etaf)*xbar/ybar)*(ystar_hat - etaf*gammaxstar_hat + zetatilde_hat)
                                    +(1-tauk)*rkbar*(kbar/ybar)*(1/muz)*(k_hat-kbar_hat(-1))
                                    -lambdaf*eps_hat
                                    -lambdaf*sharek*(k_hat-muz_hat) );     

% [37] Evolution of net foreign asset                                
a_hat = -xbar*mcx_hat - etaf*xbar*gammaxstar_hat + xbar*ystar_hat + xbar*zetatilde_hat
        +(cmbar + imbar)*gammaf_hat 
        -(cmbar*(c_hat - etac*(1-omegac)*((( (1-omegac) + omegac*((lambdamc/(lambdamc-1))/((lambdamc/(lambdamc-1))-1))^(1-etac) )^(1/(1-etac)))^(-(1-etac)))*gammamcd_hat) + imbar*(i_hat - etai*(1-omegai)*((( (1-omegai) + omegai*((lambdami/(lambdami-1))/((lambdami/(lambdami-1))-1))^(1-etai) )^(1/(1-etai)))^(-(1-etai)))*gammamid_hat))
        + (Rbar/(piebar*muz))*a_hat(-1);

% [38] Loan market clearing
((mu*mbar)/(piebar*muz))*mu_hat = -((mu*mbar)/(piebar*muz))*mbar_hat(-1) + ((mu*mbar)/(piebar*muz))*pid_hat + ((mu*mbar)/(piebar*muz))*muz_hat  
                                  +qbar*q_hat + nubar*wbar*Hbar*( w_hat + H_hat);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%%                           2.7. FOREIGN ECONOMY                        %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 


% [39] foreign inflation
 pistar_hat  = ForLag111*pistar_hat(-1)  + ForLag112*ystar_hat(-1) + ForLag113*Rstar_hat(-1)  
             +ForLag211*pistar_hat(-2)  + ForLag212*ystar_hat(-2) + ForLag213*Rstar_hat(-2) 	
             +ForLag311*pistar_hat(-3)  + ForLag312*ystar_hat(-3) + ForLag313*Rstar_hat(-3) 
      		+ForLag411*pistar_hat(-4)  + ForLag412*ystar_hat(-4) + ForLag413*Rstar_hat(-4) + ForShock11*eps_pistarhat + ForShock12*eps_ystarhat + ForShock13*eps_Rstarhat ;
 
% [40] foreign output
 ystar_hat = ForLag121*pistar_hat(-1)  + ForLag122*ystar_hat(-1) + ForLag123*Rstar_hat(-1)  
             +ForLag221*pistar_hat(-2)  + ForLag222*ystar_hat(-2) + ForLag223*Rstar_hat(-2) 	
             +ForLag321*pistar_hat(-3)  + ForLag322*ystar_hat(-3) + ForLag323*Rstar_hat(-3) 
      		+ForLag421*pistar_hat(-4)  + ForLag422*ystar_hat(-4) + ForLag423*Rstar_hat(-4) + ForShock21*eps_pistarhat + ForShock22*eps_ystarhat + ForShock23*eps_Rstarhat ;
 
% [41] foreign interest rate
 Rstar_hat  = ForLag131*pistar_hat(-1)  + ForLag132*ystar_hat(-1) + ForLag133*Rstar_hat(-1)  
             +ForLag231*pistar_hat(-2)  + ForLag232*ystar_hat(-2) + ForLag233*Rstar_hat(-2) 	
             +ForLag331*pistar_hat(-3)  + ForLag332*ystar_hat(-3) + ForLag333*Rstar_hat(-3) 
      		+ForLag431*pistar_hat(-4)  + ForLag432*ystar_hat(-4) + ForLag433*Rstar_hat(-4) + ForShock31*eps_pistarhat + ForShock32*eps_ystarhat + ForShock33*eps_Rstarhat ;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                     3. DATA AND MEASUREMENT ISSUES                    %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%[42] Link to obs. domestic inflation
data_pid = 400*(piebar-1)*piebar + 4*piebar*pid_hat;

%[43] Link to obs. wage
data_wp = 100*log(muz) + w_hat-w_hat(-1) + muz_hat;

%[44] Link to obs. consumption
data_c = 100*log(muz) + c_hat-c_hat(-1) 
      + (cbar/(cdbar+cmbar))*etac*(cdbar/cbar)*(cmbar/cbar)*( ((( (1-omegac)*(((lambdamc/(lambdamc-1))-1)/(lambdamc/(lambdamc-1)))^(1-etac) + omegac )^(1/(1-etac)))^-1) - ((( (1-omegac) + omegac*((lambdamc/(lambdamc-1))/((lambdamc/(lambdamc-1))-1))^(1-etac) )^(1/(1-etac)))^-1) )*(gammamcd_hat-gammamcd_hat(-1)) + muz_hat;

%[45] Link to obs. investment
data_i = 100*log(muz) + i_hat-i_hat(-1)
      + (ibar/(idbar+imbar))*etai*(idbar/ibar)*(imbar/ibar)*( ((( (1-omegai)*(((lambdami/(lambdami-1))-1)/(lambdami/(lambdami-1)))^(1-etai) + omegai )^(1/(1-etai)))^-1) - ((( (1-omegai) + omegai*((lambdami/(lambdami-1))/((lambdami/(lambdami-1))-1))^(1-etai) )^(1/(1-etai)))^-1) )*(gammamid_hat-gammamid_hat(-1)) 
      +  (1-tauk)*rkbar*kbar*(1/muz)*((k_hat - kbar_hat) - (k_hat(-1) - kbar_hat(-1)) ) 
      + muz_hat ;

%[46] Link to obs. nominal interest rate
data_R = 400*(Rbar-1)*Rbar + 4*Rbar*R_hat; 

%[47] Link to obs. gdp
data_y = 100*log(muz) + y_hat-y_hat(-1) + muz_hat;

%[48] Link to obs. export
data_x = 100*log(muz) + ystar_hat-ystar_hat(-1) - etaf*(gammaxstar_hat-gammaxstar_hat(-1)) + zetatilde_hat-zetatilde_hat(-1) + muz_hat;

%[49] Link to obs.import
data_m = 100*log(muz) + (cmbar/(cmbar+imbar))*(c_hat-c_hat(-1)) 
      - (cmbar/(cmbar+imbar))*(etac*(1-omegac)*(( (1-omegac) + omegac*((lambdamc/(lambdamc-1))/((lambdamc/(lambdamc-1))-1))^(1-etac) )^(1/(1-etac)))^(-(1-etac)))*(gammamcd_hat-gammamcd_hat(-1))
      + (imbar/(cmbar+imbar))*(i_hat-i_hat(-1)) 
      - (imbar/(cmbar+imbar))*(etai*(1-omegai)*(( (1-omegai) + omegai*((lambdami/(lambdami-1))/((lambdami/(lambdami-1))-1))^(1-etai) )^(1/(1-etai)))^(-(1-etai)))*(gammamid_hat-gammamid_hat(-1))
      + muz_hat;

%[50] Link to obs. consumption price
data_pic = 400*(piebar-1)*piebar + 4*piebar*pic_hat + 4*piebar*(tauc/(1+tauc))*(tauc_hat - tauc_hat(-1));

%[51] Link to obs. foreign output
data_ystar = 100*log(muz) + ystar_hat-ystar_hat(-1) + zetatilde_hat-zetatilde_hat(-1) + muz_hat;

%[52] Link to obs. foreign inflation
data_pistar = 400*(piebar-1)*piebar + 4*piebar*pistar_hat;

%[53] Link to obs. foreign interest rate
data_Rstar = 400*(Rbar-1)*Rbar + 4*Rbar*Rstar_hat;

%[54] Link to obs. employment
E_t = beta/(1+beta)*E_t(+1)+(1/(1+beta))*E_t(-1)+((1-xie)*(1-beta*xie))/((1+beta)*xie)*(H_hat-E_t); // change made by Gerret, 27.06.2017 becasue swedish data has no data about employment

///////////////////////////////////////////////////////////////////////////
//                  ENDING BLOCK I: ENDOGENOUS VARIABLES                 //
///////////////////////////////////////////////////////////////////////////

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

///////////////////////////////////////////////////////////////////////////
//                        II: EXOGENOUS VARIABLES                        //
///////////////////////////////////////////////////////////////////////////

% [55] Nonstationary technology 
muz_hat         = rhomuz*muz_hat(-1)            + eps_muzhat;

% [56] Stationary technology
eps_hat         = rhoeps*eps_hat(-1)            + eps_epshat;

% [57] Consumption preference
zetac_hat       = rhozetac*zetac_hat(-1)        + eps_zetachat;

% [58] Labor supply 
zetah_hat       = rhozetah*zetah_hat(-1)        + eps_zetahhat;

% [59] Domestic markup
lambdaf_hat     = rholambda*lambdaf_hat(-1)     + eps_lambdafhat;

% [60] imp cons goods markup
etamc_hat       = rhoetamc*etamc_hat(-1)        + eps_etamchat;

% [61] imp inv goods markup
etami_hat       = rhoetami*etami_hat(-1)        + eps_etamihat;

% [62] Risk premium
phitilde_hat    = rhophitilde*phitilde_hat(-1)  + eps_phitildehat;

% [63] Investment specific technology
upsilon_hat     = rhoiota*upsilon_hat(-1)       + eps_upsilonhat;

% [64] Monetary policy
epsR_hat        = rhoepsR*epsR_hat(-1)          + eps_epsRhat;

% [65] Markup export
lambdax_hat     = rholambdax*lambdax_hat(-1)    + eps_lambdaxhat;

% [66] Asymmetric technology
zetatilde_hat   = rhozetatilde*zetatilde_hat(-1)+ eps_zetatildehat;

% [67] Inflation target
piT_hat         = rhopietarget*piT_hat(-1)      + eps_piThat;

///////////////////////////////////////////////////////////////////////////
//               ENDING BLOCK II: EXOGENOUS VARIABLES BLOCK              //
///////////////////////////////////////////////////////////////////////////

end;



// *** Observed data ***

% Gerret & Pg, working on this
varobs data_pid data_wp data_c data_i x_hat
data_R E_t data_y data_x data_m data_pic 
data_ystar data_pistar data_Rstar;

steady;
check;

shocks;

//Foreign VAR pre-estimated as ALLV's series paper
var eps_pistarhat = (1)^2;
var eps_ystarhat  = (1)^2;
var eps_Rstarhat  = (1)^2;

//Fiscal VAR P 27.7 SHUTTING DOWN
var eps_taukhat = (0)^2;
var eps_tauwhat = (0)^2;
var eps_tauchat = (0)^2;
var eps_tauyhat = (0)^2; 
var eps_ghat    = (0)^2; 
end; 


///////////////////////////////////////////////////////////////////////////
//                     DELARING THE BAYESIAN ESTIMATIION                 //
///////////////////////////////////////////////////////////////////////////

// *** Prior distribution: ***
estimated_params; 
//use [s,nu]=inverse_gamma_specification(0.002,inf,1) to verify that 
//stdev=inf  yields indeed 2 degrees of freedom
//MA: wrong prior for truncnormal and invgamma > 4df
%-------Calvo parameters block (nominal friction)--------------------------
% probability that a firm/household is not allowed to reoptimise price/wage
xiw,,,,        beta_pdf,0.675,0.05;                      % [01] Calvo wage
xid,,,,        beta_pdf,0.675,0.05;                      % [02] Calvo domestic price
ximc,,,,       beta_pdf,0.675,0.05;                      % [03] Calvo import consumption price
ximi,,,,       beta_pdf,0.675,0.05;                      % [04] Calvo import investment price
xix,,,,        beta_pdf,0.675,0.05;                      % [05] Calvo export price
xie,,,,        beta_pdf,0.675,0.05;                      % [06] Calvo unemployment
%------------Indexations price and wage (nominal friction)----------------- 
kappaw,,,,       beta_pdf,0.5,0.15;                      % [07] Indexation wages
kappad,,,,       beta_pdf,0.5,0.15;                      % [08] Indexation prices for domestic firm
kappamc,,,,       beta_pdf,0.5,0.15;                     % [09] Indexation prices for importing cons. firm
kappami,,,,       beta_pdf,0.5,0.15;                     % [10] Indexation prices for importing inves. firm
kappax,,,,       beta_pdf,0.5,0.15;                      % [11] Indexation prices for exporting firm 
%----------------------------- Markups------------------------------------
lambdaf,,,,        normal_pdf,1.2,0.05;                  % [12] Markup demestic
lambdamc,,1.01,,   normal_pdf,1.2,0.05;                  % [13] Markup imported consumption
lambdami,,1.01,,   normal_pdf,1.2,0.05;                  % [14] Markup imported invesment
%----------------------------Real frictions--------------------------------
SS,,,,         normal_pdf,7.694,1.5;                     % [15] Investment adjustment cost, initial value: 1.5, 1 (fine, saving mod file)
b,,,,          beta_pdf,0.65,0.1;                        % [16] Consumption habit formation
%----------------------Substitution of elasticity--------------------------
etai,,,,       inv_gamma_pdf,1.5,inf;                    % [17] Subst. elasticity investment
etaf,,,,       inv_gamma_pdf,1.5,inf;                    % [18] Subst. elasticity foreign
muz,,,,        normal_pdf, 1.006,0.0005;                 % [19] Technology growth
phitilde,,,,   inv_gamma_pdf,0.01,inf;                   % [20] Risk premium
% phitildes,,,,  beta_pdf,0.5,0.1;%0.15;                 % [21] UIP modification 27.3.2018 Phuong exclude this param
%----------------------------SHOCK PROCESS---------------------------------
%-----------------Persistent paramters in AR process-----------------------
rhomuz,,,,     beta_pdf,0.85,0.1;                        % [22] Unit root tech.shock param.
rhoeps,,,,     beta_pdf,0.85,0.1;                        % [23] Stationary tech. shock param.
rhoiota,,,,    beta_pdf,0.85,0.1;                        % [24] Investment specific technology shock param.
rhozetatilde,,,,   beta_pdf,0.85,0.1;                    % [25] Asymmetric technology shock param.
rhozetac,,,,   beta_pdf,0.85,0.1;                        % [26] Consumption preference param.
rhozetah,,,,   beta_pdf,0.85,0.1;                        % [27] Labor supply param.
rhophitilde,,,,beta_pdf,0.85,0.1;                        % [28] Risk premium shock param.
rholambda,,,,   beta_pdf,0.85,0.1;                       % [29] Domestic markup shock param.(including after 2018) (white noise)
rhoetamc,,,,   beta_pdf,0.85,0.1;                        % [30] Markup, imp cons goods param. (including after 2018)
rhoetami,,,,   beta_pdf,0.85,0.1;                        % [31] Markup, imp inv goods param.(including after 2018)
rholambdax,,,,    beta_pdf,0.85,0.1;                     % [32] Markup export param. (including after 2018)
%rhoepsR,,,,    beta_pdf,0.85,0.05;                      % [] Monetary policy shock param.(including after 2018) (WHITENOISE9
%rhopietarget,,,,    beta_pdf,0.85,0.05;                 % [] Inflation target persistent param. is calibrated
%-----------------------Standard Diviation of Shock------------------------
stderr eps_muzhat,,,,   inv_gamma_pdf,0.2,inf;           % [33] unit root technology shock (including after 2018)
stderr eps_epshat,,,,   inv_gamma_pdf,0.7,inf;           % [34] Stationary technology shock
stderr eps_upsilonhat,,,,   inv_gamma_pdf,0.2,inf;       % [35] Investment specific technology shock
stderr eps_zetatildehat,,,,   inv_gamma_pdf,0.4,inf;     % [36] Asymmetric technology
stderr eps_zetachat,,,,   inv_gamma_pdf,0.2,inf;         % [37] Consumption preference shock phuong modify
stderr eps_zetahhat,,,,   inv_gamma_pdf,1,inf;           % [38] Labor supply shock, phuong modify stderr eps_zetahhat,,,,   inv_gamma_pdf,1.0*527.1575,inf
stderr eps_phitildehat,,,,   inv_gamma_pdf,0.05,inf;     % [39] Risk premium shock
stderr eps_lambdafhat,,,,   inv_gamma_pdf,1,inf;         % [40] Domestic markup shock
stderr eps_etamchat,,,,   inv_gamma_pdf,1,inf;           % [41] Markup, imp cons goods shock
stderr eps_etamihat,,,,   inv_gamma_pdf,1,inf;           % [42] Markup,  imp inv goods shock
stderr eps_lambdaxhat,,,,   inv_gamma_pdf,1,inf;         % [43] Markup export shock
stderr eps_epsRhat,,,,   inv_gamma_pdf,0.15,inf;         % [44] Monetary policy Shock
stderr eps_piThat,,,,   inv_gamma_pdf,0.05,inf;          % [45] Inflation Target Shock
%--------------------------Policy rule parameters--------------------------
//--------------------- 6 parameters in policy rule------------------------
rhoR,,,,    beta_pdf,0.8,0.05;                           % [46] Interest Rate smoothing
rpie,,,,    normal_pdf,1.8,0.1;                          % [47] Inflation response
rdeltapi,,,, normal_pdf,0.3,0.05;                        % [48] Diff. Inflation response
rx,,,, normal_pdf,0.01,0.05;                             % [49] 0.00 as prior mean, Real exchange rate response
ry,,,, normal_pdf,0.125,0.05;                            % [50] 0.05;  Output response
rdeltay,,,, normal_pdf,0.0625,0.05;                      % [51] Diff. output response
%--------------------------------------------------------------------------

end;


///////////////////////////////////////////////////////////////////////////
//                        STARTING ESTIMATIION                           //
///////////////////////////////////////////////////////////////////////////

estimation(
datafile=Trans_Aus_Dat_dynare_rw,
diffuse_filter, % to stationanize data
plot_priors=0, % default =1
mode_compute=9,%4 (Chris Sim), 7 ( fminsearch Nelder-Mead 1965), 9 (Covariance Matrix Adaptation Evolution Strategy) algorithm of Hansen and Kern (2004))
mh_replic= 250000,      % THE MOST IMPORTANCE. Number of draws for each Makov chain. Default: 20,000
mh_nblocks = 1,   % THE MOST IMPORTANCE. Number of parallel chains for Metropolis-Hasting Algorithm (Default=2, very low). it should be at least 5
mh_drop = 0.45,    % the number of burn-in. default =0.5
mh_jscale = 0.26,%0.23,%0.24,%0.25,  % THE MOST IMPORTANCE. The scale for jumping distribution in the MH algorithm (default =0.2, rarely satisfactory)
                  % this scale must be tunned to make sure the acceptance rate ranging btw 0.2 and 0.4
                  % when Phuong set the jumping scale of 0.2 as a default number, then the acceptance ratio is
                  % over 0.4 (too high in comparison to literature only 0.2 and 0.4)
                  % that's why P increase the jump scale from default level of 0.2 to 0.3
                  % as a result, the acceptance ratio lies on the range btw 0.2 and 0.4
                  % the rule to adjust the jumping scale (c)
                  % if the acceptance ratio (R) is TOO LOW, then the jumping scale (c) should be REDUCED (WHY?)
                  % if the acceptance ratio (R) is TOO HIGH, then the jumping scale (c) should be INCREASED (WHY?)load
//load_mh_file,
mode_file=ausopen_mode, % to use the previous likelihood result
mode_check_neighbourhood_size =1000,
//mode_check,
forecast=12)data_pid data_wp data_c data_i data_R E_t data_y ; 

